Installation
============

.. include:: ../README.rst
   :start-after: _installation_start:
   :end-before:  _installation_end:

.. include:: ../README.rst
   :start-after: _appendix_start:
   :end-before:  _appendix_end: